@@ -9,11 +9,7 @@
 #define _SOFTKVER_H_
 
 #ifndef NSS_DISABLE_ECC
-#ifdef NSS_ECC_MORE_THAN_SUITE_B
-#define SOFTOKEN_ECC_STRING " Extended ECC"
-#else
 #define SOFTOKEN_ECC_STRING " Basic ECC"
-#endif
 #else
 #define SOFTOKEN_ECC_STRING ""
 #endif
@@ -25,11 +21,11 @@
  * The format of the version string should be
  *     "<major version>.<minor version>[.<patch level>[.<build number>]][ <ECC>][ <Beta>]"
  */
-#define SOFTOKEN_VERSION  "3.20.2" SOFTOKEN_ECC_STRING
-#define SOFTOKEN_VMAJOR   3
-#define SOFTOKEN_VMINOR   20
-#define SOFTOKEN_VPATCH   2
-#define SOFTOKEN_VBUILD   0
-#define SOFTOKEN_BETA     PR_FALSE
+#define SOFTOKEN_VERSION "3.29.2" SOFTOKEN_ECC_STRING
+#define SOFTOKEN_VMAJOR 3
+#define SOFTOKEN_VMINOR 29
+#define SOFTOKEN_VPATCH 2
+#define SOFTOKEN_VBUILD 0
+#define SOFTOKEN_BETA PR_FALSE
 
 #endif /* _SOFTKVER_H_ */
